<?php
/* $Id: spanish-iso-8859-15.inc.php 11212 2008-04-23 16:28:20Z lem9 $ */

$charset = 'iso-8859-15';
$text_dir = 'ltr';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// Atajos para Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$mysql_5_0_doc_lang = 'es';

$day_of_week = array('Dom', 'Lun', 'Mar', 'Mie', 'Jue', 'Vie', 'Sab');
$month = array('Ene', 'Feb', 'Mar', 'Abr', 'May', 'Jun', 'Jul', 'Ago', 'Sep', 'Oct', 'Nov', 'Dic');
// Ver http://www.php.net/manual/es/function.strftime.php para definir
// la variable siguiente
$datefmt = '%d-%m-%Y a las %H:%M:%S';
$timespanfmt = '%s das, %s horas, %s minutos y %s segundos';

$strAbortedClients = 'Abortado';
$strAccessDenied = 'Acceso denegado ';
$strAccessDeniedCreateConfig = 'La razn ms probable es que usted no cre un archivo de configuracin. Utilice %1$ssetup script%2$s para crear una.';
$strAccessDeniedExplanation = 'phpMyAdmin intent conectarse con el servidor MySQL, y el servidor rechaz esta conexin. Deber revisar el host, nombre de usuario y contrasea en config.inc.php y asegurarse que corresponden con la informacin provista por el administrador del servidor MySQL.';
$strAction = 'Accin';
$strAddAutoIncrement = 'Aadir el valor AUTO_INCREMENT';
$strAddClause = 'Aada %s';
$strAddConstraints = 'Aadir restricciones';
$strAddDeleteColumn = 'Aadir/borrar columna de criterio';
$strAddDeleteRow = 'Aadir/borrar fila de criterio';
$strAddFields = 'Aadir %s campo(s)';
$strAddHeaderComment = 'Aadir su propio comentario en el encabezado (\\n segmenta las oraciones)';
$strAddIntoComments = 'Aadir en los comentarios';
$strAddNewField = 'Insertar nuevo campo';
$strAddPrivilegesOnDb = 'Aadir privilegios a esta base de datos';
$strAddPrivilegesOnTbl = 'Aadir privilegios a esta tabla';
$strAddSearchConditions = 'Insertar las condiciones de bsqueda (cuerpo de la clusula "where"):';
$strAddToIndex = 'Aadir al ndice &nbsp;%s&nbsp;columna(s)';
$strAddUser = 'Agregar un nuevo usuario';
$strAddUserMessage = 'Ha agregado un nuevo usuario.';
$strAdministration = 'Administracin';
$strAffectedRows = 'Filas afectadas: ';
$strAfter = 'Despus de %s';
$strAfterInsertBack = 'Volver';
$strAfterInsertNewInsert = 'Insertar un nuevo registro';
$strAfterInsertNext = 'Editar la siguiente fila';
$strAfterInsertSame = 'Volver a esta pgina';
$strAllowInterrupt = 'Permita la interrupcin de la importacin en el caso de que el script detecte que se ha acercado a su lmite de tiempo. Esto podra ser un buen mtodo para importar archivos grandes; sin embargo, puede daar las transacciones.';
$strAllTableSameWidth = 'Mostrar todas las tablas que tienen el mismo ancho?';
$strAll = 'Todos/as';
$strAlterOrderBy = 'Modificar el ORDER BY de la tabla';
$strAnalyzeTable = 'Analizar la tabla';
$strAndThen = 'y luego';
$strAnd = 'y luego';
$strAngularLinks = 'Enlaces angulares';
$strAnIndex = 'Se aadi un ndice en %s';
$strAny = 'cualquiera';
$strAnyHost = 'Cualquier servidor';
$strAnyUser = 'Cualquier usuario';
$strApproximateCount = 'Podra ser aproximado.  Lase la FAQ 3.11';
$strAPrimaryKey = 'Se aadi una clave primaria en %s';
$strArabic = 'rabe';
$strArmenian = 'Armenio';
$strAscending = 'Ascendente';
$strAtBeginningOfTable = 'Al comienzo de la tabla';
$strAtEndOfTable = 'Al final de la tabla';
$strAttr = 'Atributos';
$strAutomaticLayout = 'Diseo automtico';

$strBack = 'Volver';
$strBaltic = 'Bltico';
$strBeginCut = 'INICIO DEL CORTE';
$strBeginRaw = 'INICIO DEL VOLCADO';
$strBinary = ' Binario ';
$strBinaryDoNotEdit = ' Binario - no editar! ';
$strBinaryLog = 'Log binario';
$strBinLogEventType = 'Tipo de evento';
$strBinLogInfo = 'Informacin';
$strBinLogName = 'Nombre con el cual se registr';
$strBinLogOriginalPosition = 'Posicin original';
$strBinLogPosition = 'Posicin';
$strBinLogServerId = 'ID del servidor';
$strBookmarkAllUsers = 'Permitir que todo usuario pueda acceder a este favorito';
$strBookmarkCreated = 'El favorito %s fue creado';
$strBookmarkDeleted = 'El favorito ha sido borrado.';
$strBookmarkLabel = 'Etiqueta';
$strBookmarkQuery = 'Consulta guardada en favoritos';
$strBookmarkReplace = 'Reemplazar el favorito existente que tenga el mismo nombre';
$strBookmarkThis = 'Guardar esta consulta en favoritos';
$strBookmarkView = 'Solamente ver';
$strBrowseDistinctValues = 'Navegar los valores distintivos';
$strBrowse = 'Examinar';
$strBrowseForeignValues = 'Mostrar los valores extranjeros';
$strBufferPoolActivity = 'Actividad de la memoria (bfer) de trnsito comn';
$strBufferPool = 'Total de memoria del bfer'; 
$strBufferPoolUsage = 'Total de memoria del bfer consumido'; 
$strBufferReadMissesInPercent = 'Leer los fallos en %';
$strBufferReadMisses = 'Leer los fallos';
$strBufferWriteWaits = 'Escribir las esperas';
$strBufferWriteWaitsInPercent = 'Escribir las esperas en %';
$strBulgarian = 'Blgaro';
$strBusyPages = 'Pginas activas'; 
$strBzError = 'Si desea usar las opciones de compresin Bz2, deber actualizar su php a una versin ms reciente. phpMyAdmin no fue capaz de comprimir el dump debido a que est daada o inaccesible la extensin Bz2 en esta versin de php. Le recomendamos que cambie el parmetro <code>$cfg[\'BZipDump\']</code> en su archivo de configuracin phpMyAdmin a <code>FALSE</code>. Lea el reporte de "bugs" de php %s para mayor informacin.';
$strBzip = '"Comprimido con bzip"';

$strCalendar = 'Calendario';
$strCancel = 'Cancelar';
$strCanNotLoadExportPlugins = 'No se cargaron los plugins de exportacin.  Por favor, revise su instalacin!';
$strCanNotLoadImportPlugins = 'No se pudieron cargar los plugins de importacin, por favor revise su instalacin';
$strCannotLogin = 'El servidor MySQL no autoriz su ingreso';
$strCantLoad = 'no se pudo cargar la extensin %s,<br />por favor revise su configuracin de PHP.';
$strCantLoadRecodeIconv = 'No se puede cargar iconv o recodificar una extensin necesaria para la conversin de juegos de caracteres, configure php para permitir el uso de estas extensiones o desactive la conversin de juegos de caracteres en phpMyAdmin.';
$strCantRenameIdxToPrimary = 'No puede cambiar el nombre del ndice a PRIMARY!';
$strCantUseRecodeIconv = 'No se puede utilizar iconv ni libiconv ni la funcin recode_string mientras se carga la extensin de informes. Comprueba la configuracin de php.';
$strCardinality = 'Cardinalidad';
$strCaseInsensitive = 'independiente de maysculas y minsculas';
$strCaseSensitive = 'dependiente de maysculas y minsculas';
$strCentralEuropean = 'Europeo central';
$strChange = 'Cambiar';
$strChangeCopyModeCopy = '...mantener el anterior.';
$strChangeCopyMode = 'Crear un nuevo usuario con los mismos privilegios y...';
$strChangeCopyModeDeleteAndReload = ' ...borrar el viejo de las tablas de usuario y luego volver a cargar los privilegios.';
$strChangeCopyModeJustDelete = ' ...borrar el viejo de las tablas de usuario.';
$strChangeCopyModeRevoke = ' ...revocar todos los privilegios activos del viejo y eliminarlo despus.';
$strChangeCopyUser = 'Cambiar la informacin de la cuenta / Copiar el usuario';
$strChangeDisplay = 'Elegir el campo a mostrar';
$strChangePassword = 'Cambio de contrasea';
$strCharset = 'Juego de caracteres';
$strCharsetOfFile = 'Juego de caracteres del archivo:'; 
$strCharsetsAndCollations = 'Juego de caracteres y sus cotejamientos'; 
$strCharsets = 'Juegos de caracteres'; 
$strCheckAll = 'Marcar todos/as';
$strCheckOverhead = 'Marcar las tablas con residuo a depurar';
$strCheckPrivsLong = 'Revisar los privilegios para la base de datos &quot;%s&quot;.';
$strCheckPrivs = 'Revisar los privilegios';
$strCheckTable = 'Revisar la tabla';
$strChoosePage = 'Elegir la pgina a editar';
$strColComFeat = 'Mostrando los comentarios de la columna';
$strCollation = 'Cotejamiento';
$strColumnNames = 'Nombre de las columnas';
$strColumnPrivileges = 'Privilegios especficos para la columna';
$strCommand = 'Comando';
$strComments = 'Comentarios';
$strCommentsForTable = 'COMENTARIOS PARA LA TABLA';
$strCompatibleHashing = 'Compatible con MySQL&nbsp;4.0';
$strCompleteInserts = 'Completar los INSERTS';
$strCompression = 'Compresin';
$strCompressionWillBeDetected = 'La compresin escogida para el archivo a importar se detectar automticamente de: %s';
$strConfigDefaultFileError = 'No fue posible cargar la configuracin predeterminada desde: "%1$s"';
$strConfigFileError = 'phpMyAdmin no puede leer el fichero de configuracin!<br />Esto puede suceder si php encuentra un error sintctico en l o bien php no puede encontrar el fichero.<br />Intente acceder al fichero de configuracin directamente mediante el siguiente enlace y compruebe el(los) mensaje(s) de error que reciba. En muchas ocasiones falta una coma o punto y coma en algn sitio.<br />Si recibe una pgina en blanco, todo est correcto.';
$strConfigureTableCoord = 'Configure las coordenadas para la tabla %s';
$strConnectionError = 'No se estableci la conexin: los parmetros estn incorrectos.';
$strConnections = 'Conexiones';
$strConstraintsForDumped = 'Filtros para las tablas descargadas (dump)';
$strConstraintsForTable = 'Filtros para la tabla';
$strControluserFailed = 'La conexin para controluser, como est definida en su configuracin, fracas.';
$strCookiesRequired = 'Las "cookies" deben estar habilitadas.';
$strCopy = 'Copiar';
$strCopyDatabaseOK = 'La base de datos %s ha sido copiada a %s';
$strCopyTable = 'Copiar la tabla a (base de datos<b>.</b>tabla):';
$strCopyTableOK = 'La tabla %s se copi a %s.';
$strCopyTableSameNames = 'No es posible copiar la tabla a la misma!';
$strCouldNotKill = 'phpMyAdmin no fue capaz de destruir el proceso %s. Probablemente ya ha sido cerrado.';
$strCreate = 'Crear';
$strCreateDatabaseBeforeCopying = 'CREAR BASE DE DATOS antes de copiar';
$strCreateIndex = 'Crear un ndice en&nbsp;%s&nbsp;columna(s)';
$strCreateIndexTopic = 'Crear un nuevo ndice';
$strCreateNewDatabase = 'Crear nueva base de datos';
$strCreateNewTable = 'Crear nueva tabla en la base de datos %s';
$strCreatePage = 'Crear una nueva pgina';
$strCreatePdfFeat = 'Creacin de los PDF';
$strCreateRelation = 'Crear relacin';
$strCreateTable  = 'Crear tabla';
$strCreateUserDatabase = 'Base de datos para el usuario';
$strCreateUserDatabaseName = 'Crear base de datos con el mismo nombre y otorgue todos los privilegios';
$strCreateUserDatabaseNone = 'Ninguna';
$strCreateUserDatabaseWildcard = 'Otorgue todos los privilegios al nombre que contiene comodn (username\_%)';
$strCreationDates = 'Fechas de creacin/actualizacin/revisin';
$strCriteria = 'Criterio';
$strCroatian = 'Croata';
$strCSV = 'CSV';
$strCyrillic = 'Cirlico';
$strCzech = 'Checo';
$strCzechSlovak = 'Checo-Eslovaco';

$strDanish = 'Dans';
$strDatabase = 'Base de datos';
$strDatabaseEmpty = 'El nombre de la base de datos est vaco!';
$strDatabaseExportOptions = 'Opciones de exportacin de la base de datos';
$strDatabaseHasBeenDropped = 'La base de datos %s ha sido eliminada.';
$strDatabases = 'Bases de datos';
$strDatabasesDropped = '%s bases de datos han sido eliminadas exitosamente.';
$strDatabasesStatsDisable = 'Desactivar las estadsticas';
$strDatabasesStatsEnable = 'Activar las estadsticas';
$strDatabasesStats = 'Estadsticas de la base';
$strDatabasesStatsHeavyTraffic = 'Nota: Activar aqu las estadsticas de la base de datos podra causar trfico pesado entre el servidor web y el servidor MySQL.';
$strData = 'Datos';
$strDataDict = 'Diccionario de datos';
$strDataOnly = 'Solamente datos';
$strDataPages = 'Pginas que contienen datos'; 
$strDBComment = 'Comentario de la base de datos: ';
$strDBCopy = 'Copiar la base de datos a';
$strDbIsEmpty = 'La base de datos, parece estar vaca!';
$strDbPrivileges = 'Privilegios especficos para la base de datos';
$strDBRename = 'Cambiar el nombre de la base de datos a';
$strDbSpecific = 'especfico para la base de datos';
$strDefaultEngine = '%s es el motor de almacenamiento predeterminado en este servidor MySQL.';
$strDefault = 'Predeterminado';
$strDefaultValueHelp = 'Para valores predeterminados, por favor ingrese solamente un valor, sin caracteres de escape \"\\\" ni comillas, usando este formato: a';
$strDefragment = 'Defragmentar la tabla';
$strDelayedInserts = 'Usar "inserts" con retraso';
$strDeleteAndFlush = 'Borrar a los usuarios y luego volver a cargar los privilegios.';
$strDeleteAndFlushDescr = 'Este es el modo ms limpio, pero volver a cargar los privilegios puede tomar tiempo.';
$strDelete = 'Borrar';
$strDeleted = 'La fila se ha borrado';
$strDeletedRows = 'Filas borradas: ';
$strDeleteNoUsersSelected = 'No se han seleccionado usuarios para eliminar!';
$strDeleteRelation = 'Eliminar la relacin';
$strDeleting = 'Borrando %s';
$strDelimiter = 'Delimitador';
$strDelOld = 'La pgina actual tiene referencias a tablas que ya no existen.  Desea eliminar esas referencias?';
$strDescending = 'Descendente';
$strDescription = 'Descripcin';
$strDesigner = 'Diseador';
$strDesignerHelpDisplayField = 'El campo Display se halla en color rosado. Para activar o desactivar un campo como un campo Display, d clic en el cono "Seleccione el campo a mostrar", luego d clic en el nombre apropiado del campo.';
$strDictionary = 'diccionario';
$strDirectLinks = 'Enlaces directos';
$strDirtyPages = 'Pginas que requieren ser depuradas'; 
$strDisabled = 'Deshabilitado';
$strDisableForeignChecks = 'Deshabilitar la revisin de las llaves extranjeras (foreign keys)';
$strDisplayFeat = 'Mostrar las opciones';  //Features = opciones, componentes?
$strDisplayOrder = 'Mostrar en este orden:';
$strDisplayPDF = 'Mostrar esquema PDF';
$strDoAQuery = 'Hacer una consulta (comodn: "%")';
$strDocSQL = 'DocSQL';
$strDocu = 'Documentacin';
$strDoYouReally = 'Realmente desea ';
$strDropDatabaseStrongWarning = 'Est a punto de DESTRUIR una base de datos completa!';
$strDrop = 'Eliminar';
$strDropUsersDb = 'Eliminar las bases de datos que tienen los mismos nombres que los usuarios.';
$strDumpingData = 'Volcar la base de datos para la tabla';
$strDumpSaved = 'Su archivo (MySQL dump) ha sido guardado con el nombre %s.';
$strDumpXRows = 'Volcar %s filas empezando por la fila %s.';
$strDynamic = 'dinmico/a';

$strEdit = 'Editar';
$strEditPDFPages = 'Editar las pginas PDF';
$strEditPrivileges = 'Editar los privilegios';
$strEffective = 'Efectivo/a';
$strEmptyResultSet = 'MySQL ha devuelto un valor vaco (i.e., cero columnas).';
$strEmpty = 'Vaciar';
$strEnabled = 'Habilitado';
$strEncloseInTransaction = 'Incluir lo exportado en una transaccin';
$strEndCut = 'FIN DEL CORTE';
$strEnd = 'Fin';
$strEndRaw = 'FIN DEL VOLCADO';
$strEngineAvailable = '%s est disponible en este servidor MySQL.';
$strEngineDisabled = '%s ha sido deshabilitado para este motor de almacenamiento.';
$strEngines = 'Motores';
$strEngineUnsupported = 'Este servidor MySQL no es compatible con el motor de almacenamiento %s.'; 
$strEnglish = 'Ingls';
$strEnglishPrivileges = ' Nota: Los nombres de los privilegios de MySQL estn expresados en ingls ';
$strError = 'Error';
$strErrorInZipFile = 'Error en el archivo ZIP:';
$strErrorRelationAdded = 'Error: no se aadi la relacin.';
$strErrorRelationExists = 'Error: la relacin ya existe.';
$strErrorRenamingTable = 'Error al cambiar el nombre de la tabla %1$s a %2$s';
$strErrorSaveTable = 'Error guardando las coordenadas para el Diseador.';
$strEscapeWildcards = 'Los comodines _ y % deben acompaarse de \ para usarlos de manera literal';
$strEsperanto = 'Esperanto';
$strEstonian = 'Estonio';
$strEvent = 'Evento';
$strExcelEdition = 'Edicin Excel';
$strExecuteBookmarked = 'Ejecute la consulta marcada previamente';
$strExplain = 'Explicar el SQL';
$strExport = 'Exportar';
$strExportImportToScale = 'Exporte/Importe a escala';
$strExportMustBeFile = 'El formato de exportacin seleccionado debe grabarse en el archivo!';
$strExtendedInserts = 'INSERTs extendidos';
$strExtra = 'Extra';

$strFailedAttempts = 'Intentos fallidos';
$strField = 'Campo';
$strFieldHasBeenDropped = 'Se elimin el campo %s';
$strFieldInsertFromFileTempDirNotExists = 'Se detect un error al trasladar el archivo cargado, ver FAQ 1.11';
$strFields = 'Campos';
$strFieldsEnclosedBy = 'Campos encerrados por';
$strFieldsEscapedBy = 'Caracter de escape';
$strFieldsTerminatedBy = 'Campos terminados en';
$strFileAlreadyExists = 'El archivo %s ya existe en el servidor, cambie el nombre del archivo o revise la opcin de sobreescritura.';
$strFileCouldNotBeRead = 'No fue posible leer el archivo';
$strFileNameTemplateDescriptionDatabase = 'nombre de la base de datos';
$strFileNameTemplateDescription = 'Este valor es interpretado usando %1$sstrftime%2$s; as, usted puede usar cadenas de caracteres para formatear el tiempo. De manera adicional, sucedern las siguientes transformaciones: %3$s. El texto restante se mantendr como est.';
$strFileNameTemplateDescriptionServer = 'nombre del servidor';
$strFileNameTemplateDescriptionTable = 'nombre de la tabla';
$strFileNameTemplate = 'Plantilla del nombre del archivo';
$strFileNameTemplateRemember = 'recordar la plantilla';
$strFiles = 'Archivos';
$strFileToImport = 'Archivo a importar';
$strFixed = 'fijo';
$strFlushPrivilegesNote = 'Nota: phpMyAdmin obtiene los privilegios de los usuarios \'directamente de las tablas de privilegios MySQL\'. El contenido de estas tablas puede diferir de los privilegios que usa el servidor si es que se han realizado cambios manuales en l. En este caso, nuevamente deber %scargar la pgina de privilegios%s antes de continuar.';
$strFlushQueryCache = 'Vaciar el cache de consultas';
$strFlushTables = 'Vaciar el cache de todas las tablas';
$strFlushTable = 'Vaciar el cach de la tabla ("FLUSH")';
$strFontSize = 'Tamao del font';
$strForeignKeyError = 'Error creando llaves extranjeras (foreign keys).  Revise los tipos de datos';
$strFormat = 'Formato';
$strFormEmpty = 'Falta un valor en el formulario!';
$strFreePages = 'Pginas libres'; 
$strFullText = 'Textos completos';
$strFunction = 'Funcin';
$strFunctions = 'Funciones';

$strGenBy = 'Generado por';
$strGeneralRelationFeat = 'Opciones de relacin general';  //Features = opciones, componentes?
$strGenerate = 'Generar';
$strGeneratePassword = 'Generar la contrasea';
$strGenTime = 'Tiempo de generacin';
$strGeorgian = 'Georgiano';
$strGerman = 'Alemn';
$strGlobal = 'global';
$strGlobalPrivileges = 'Privilegios globales';
$strGlobalValue = 'Valor global';
$strGo = 'Continuar';
$strGrantOption = 'Conceder';
$strGreek = 'Griego';
$strGzip = '"Comprimido con gzip"';

$strHandler = 'Gestor';
$strHasBeenAltered = 'fue modificada.';
$strHasBeenCreated = 'se cre.';
$strHaveToShow = 'Debe elegir al menos una columna para mostrar';
$strHebrew = 'Hebreo';
$strHelp = 'Ayuda';
$strHexForBLOB = 'Use hexadecimal para BLOB';
$strHide         = 'Ocultar';
$strHideShowAll = 'Ocultar/mostrar todo';
$strHideShowNoRelation = 'Ocultar/mostrar Tablas que no tengan relacin';
$strHomepageOfficial = 'Pgina oficial de phpMyAdmin';
$strHome = 'Pgina de inicio';
$strHostEmpty = 'El nombre del servidor est vaco!!';
$strHost = 'Servidor';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHungarian = 'Hngaro';

$strIcelandic = 'Islands';
$strId = 'Identificacin';
$strIdxFulltext = 'Texto completo';
$strIEUnsupported = 'Internet Explorer no reconoce esa funcin.';
$strIgnoreDuplicates = 'Ignore las filas duplicadas';
$strIgnore = 'Ignorar';
$strIgnoreInserts = 'Usar la opcin ignore inserts';
$strImportExportCoords = 'Importar/Exportar coordenadas para el esquema PDF';
$strImportFiles = 'Importar archivos';
$strImportFormat = 'Formato del archivo importado';
$strImport = 'Importar';
$strImportSuccessfullyFinished = 'La importacin se ejecut exitosamente, se ejecutaron %d consultas.';
$strIndexes = 'ndices';
$strIndexesSeemEqual = 'Los siguientes ndices parecen ser idnticos y uno de ellos debe ser removido:';
$strIndexHasBeenDropped = 'El ndice %s ha sido eliminado';
$strIndex = 'ndice';
$strIndexName = 'Nombre del ndice&nbsp;:';
$strIndexType = 'Tipo de ndice&nbsp;:';
$strIndexWarningTable = 'Problemas con los ndices de la tabla `%s`';
$strInnoDBAutoextendIncrementDesc = 'El tamao a incrementar para que se extienda el ancho de una tabla capaz de autoextenderse cuando se llena.'; 
$strInnoDBAutoextendIncrement = 'Incremente el valor AUTOEXTEND'; 
$strInnoDBBufferPoolSizeDesc = 'El tamao de la memoria intermedia (bfer) usado por InnoDB para almacenar, en el cache, los datos e ndices de sus tablas.';
$strInnoDBBufferPoolSize = 'Tamao de la memoria (bfer) de trnsito comn';
$strInnoDBDataFilePath = 'Archivos de datos'; 
$strInnoDBDataHomeDirDesc = 'La parte constante de la ruta del directorio para todos los archivos de datos InnoDB.'; 
$strInnoDBDataHomeDir = 'Directorio raz de los datos';
$strInnoDBPages = 'pginas';
$strInnoDBRelationAdded = 'Se aadi la relacin InnoDB';
$strInnodbStat = 'Estado del InnoDB';
$strInsecureMySQL = 'Su archivo de configuracin contiene parmetros (root sin contrasea) que corresponden a la cuenta privilegiada predeterminada de MySQL. Su servidor de MySQL est usando estos valores, lo que constituye una vulnerabilidad.  Se le recomienda corregir esta brecha de seguridad.  Por ejemplo, desde la pgina de inicio de phpMyAdmin seleccione Privilegios y agregue la contrasea a root@localhost.  Deber escribir la misma contrasea en config.inc.php de phpMyAdmin';
$strInsertAsNewRow = 'Insertar como una nueva fila';
$strInsertedRowId = 'Se insert la ID de la fila:';
$strInsertedRows = 'Filas insertadas:';
$strInsert = 'Insertar';
$strInternalNotNecessary = '* No es necesaria una relacin interna cuando tambin existe en InnoDB.';
$strInternalRelationAdded = 'Se aadi la relacin interna';
$strInternalRelations = 'Relaciones internas';
$strInUse = 'en uso';
$strInvalidAuthMethod = 'El mtodo de autenticacin no es vlido en la configuracin actual:';
$strInvalidColumnCount = 'El nmero de columnas debe ser superior a cero.';
$strInvalidColumn = 'Las columnas especificadas (%s) no son vlidas!';
$strInvalidCSVFieldCount = 'El nmero de campos de los datos CSV en la lnea %d no es vlido.';
$strInvalidCSVFormat = 'El formato de los datos CSV en la lnea %d no es vlido.';
$strInvalidCSVParameter = 'Parmetro no vlido para importar CSV: %s';
$strInvalidDatabase = 'La base de datos no es vlida';
$strInvalidFieldAddCount = 'Debe aadir al menos un campo.';
$strInvalidFieldCount = 'La tabla debe tener al menos un campo.';
$strInvalidLDIImport = 'Este plugin no tiene soporte para importaciones comprimidas!';
$strInvalidRowNumber = '%d no es un nmero de fila vlido.';
$strInvalidServerHostname = 'El nombre del host no es vlido para el servidor %1$s. Por favor, revise su configuracin.';
$strInvalidServerIndex = 'No es vlido el ndice del servidor: "%s"';
$strInvalidTableName = 'El nombre de la tabla no es vlido';

$strJapanese = 'Japons';
$strJoins = 'Vnculos (Joins)';
$strJumpToDB = 'Saltar a la base de datos &quot;%s&quot;.';
$strJustDeleteDescr = 'Los usuarios &quot;borrados&quot; an podrn acceder al servidor de manera usual hasta que los privilegios se hayan vuelto a cargar.';
$strJustDelete = 'Solamente borrar a los usuarios de la tabla de privilegios.';

$strKeepPass = 'No cambiar la contrasea';
$strKeyCache = 'Cache principal';
$strKeyname = 'Nombre de la clave';
$strKill = 'Matar el proceso';
$strKnownExternalBug = 'La funcionalidad %s est afectada por un fallo conocido, vea %s';
$strKorean = 'Coreano';

$strLandscape = 'Orientacin horizontal';
$strLanguage = 'Idioma';
$strLanguageUnknown = 'Idioma desconocido: %1$s.';
$strLatchedPages = 'Pginas vinculadas';
$strLatexCaption = 'Subtitulado de la tabla';
$strLatexContent = 'Contenido de la tabla __TABLE__';
$strLatexContinuedCaption = 'Continuacin del subtitulado de la tabla';
$strLatexContinued = '(contina)';
$strLatexIncludeCaption = 'Incluir el subtitulado de la tabla';
$strLatexLabel = 'Clave de la etiqueta';
$strLaTeX = 'LaTeX';
$strLatexStructure = 'Estructura de la tabla __TABLE__';
$strLatvian = 'Letn';
$strLDI = 'CSV usando LOAD DATA';
$strLDILocal = 'Use la palabra clave LOCAL';
$strLengthSet = 'Longitud/Valores*';
$strLimitNumRows = 'registros por pgina';
$strLinesTerminatedBy = 'Lneas terminadas en';
$strLinkNotFound = 'No se encontr el enlace';
$strLinksTo = 'Enlaces a';
$strLithuanian = 'Lituano';
$strLocalhost = 'Local';
$strLocationTextfile = 'Localizacin del archivo de texto';
$strLoginInformation = 'Informacin de la cuenta';
$strLogin = 'Iniciar sesin';
$strLogout = 'Salir';
$strLogPassword = 'Contrasea:';
$strLogServer = 'Servidor';
$strLogUsername = 'Usuario:';
$strLongOperation = 'Esta operacin podra tomar algn tiempo. Proceder de todas formas?';

$strMaxConnects = 'Nmero mx. de conexiones concurrentes';
$strMaximalQueryLength = 'Longitud mxima de la consulta creada';
$strMaximumSize = 'Tamao mximo: %s%s';
$strMbExtensionMissing = 'No se hall la extensin PHP mbstring y al parecer usted est usando tipografa multibyte. phpMyAdmin no puede cortar correctamente las cadenas de caracteres sin la extensin mbstring y podra dar resultados inesperados.';
$strMbOverloadWarning = 'Usted ha activado mbstring.func_overload en su configuracin PHP. Esta opcin es incompatible con phpMyAdmin y podra causar la prdida de algunos datos!';
$strMIME_available_mime = 'MIME-types disponibles';
$strMIME_available_transform = 'Transformaciones disponibles';
$strMIME_description = 'Descripcin';
$strMIME_MIMEtype = 'MIME-type';
$strMIME_nodescription = 'No hay una descripcin disponible para esta transformacin.<br />Por favor pregunte al autor lo que %s hace.';
$strMIME_transformation_note = 'Para una lista de opciones de transformacin disponibles y sus transformaciones MIME-type transformations, d clic en %stransformation descriptions%s';
$strMIME_transformation_options_note = 'Por favor ingrese los valores para las opciones de transformacin usando este formato: \'a\',\'b\',\'c\'...<br />Si alguna vez requiere insertar un Backslash ("\") o comilla sencilla ("\'") entre esos valores, use backslash (por ejemplo \'\\\\xyz\' o \'a\\\'b\').';
$strMIME_transformation_options = 'Opciones de transformacin';
$strMIME_transformation = 'Transformacin del navegador';
$strMIMETypesForTable = 'TIPOS MIME PARA LA TABLA';
$strMIME_without = 'MIME-types impresos en itlicas no tienen una funcin de transformacin adicional';
$strModifications = 'Se han guardado las modificaciones';
$strModifyIndexTopic = 'Modificar un ndice';
$strModify = 'Modificar';
$strMoveMenu = 'Mover el Men';
$strMoveTable = 'Mover tabla a (Base de datos<b>.</b>tabla):';
$strMoveTableOK = 'La tabla %s ha sido movida a %s.';
$strMoveTableSameNames = 'No es posible mover la tabla a la misma!';
$strMultilingual = 'multilinge';
$strMyISAMDataPointerSizeDesc = 'El tamao predeterminado del puntero de datos en bytes, para su uso en CREATE TABLE para las tablas MyISAM cuando no se ha especificado la opcin MAX_ROWS.';
$strMyISAMDataPointerSize = 'Tamao del puntero de datos';
$strMyISAMMaxExtraSortFileSizeDesc = 'Si el archivo temporal usado para la generacin rpida de ndices MyISAM fuese mayor que el uso del key cache por la cantidad especificada aqu, preferir el mtodo key cache.';
$strMyISAMMaxExtraSortFileSize = 'Tamao mximo de los archivos temporales durante la generacin del ndice'; 
$strMyISAMMaxSortFileSizeDesc = 'El tamao mximo del archivo temporal que MySQL puede generar mientras genera un nuevo ndice MyISAM del archivo temporal (durante REPAIR TABLE, ALTER TABLE, o LOAD DATA INFILE).';
$strMyISAMMaxSortFileSize = 'Tamao mximo para los archivos temporales generados durante la organizacin';
$strMyISAMRecoverOptionsDesc = 'La modalidad para la recuperacin automtica de tablas MyISAM cadas catastrficamente, como fuera determinado mediante la opcin al arranque del servidor --myisam-recover.'; 
$strMyISAMRecoverOptions = 'Modalidad de recuperacin automtica';
$strMyISAMRepairThreadsDesc = 'Si este valor es superior a 1, se generan en paralelo los ndices de las tablas MyISAM (cada ndice con su propio proceso) durante el proceso \"Reparar mediante organizacin\".';
$strMyISAMRepairThreads = 'Reparar los procesos'; 
$strMyISAMSortBufferSizeDesc = 'La cantidad de memoria que se asigna para organizar los ndices MyISAM durante la operacin REPAIR TABLE o cuando se generan ndices con CREATE INDEX o ALTER TABLE.';
$strMyISAMSortBufferSize = 'Organizar el tamao del bfer de memoria';
$strMySQLCharset = 'Juegos de caracteres de MySQL';
$strMysqlClientVersion = 'Versin del cliente';
$strMySQLConnectionCollation = 'Cotejamiento de las conexiones MySQL';
$strMysqlLibDiffersServerVersion = 'Su versin de librera PHP MySQL  %s es distinta de aquella de su versin de servidor MySQL %s. Esto puede ocasionar un comportamiento impredecible.';
$strMySQLSaid = 'MySQL ha dicho: ';
$strMySQLShowProcess = 'Mostrar procesos';
$strMySQLShowStatus = 'Mostrar informacin de tiempo de ejecucin de MySQL';
$strMySQLShowVars = 'Mostrar las variables del sistema MySQL';

$strName = 'Nombre';
$strNext = 'Prxima';
$strNoActivity = 'No ha habido actividad desde hace %s o ms segundos, por favor reingrese al sitio';
$strNoDatabases = 'No hay bases de datos';
$strNoDatabasesSelected = 'No se seleccionaron bases de datos.';
$strNoDataReceived = 'No se recibieron datos para importar. O no se envi el nombre del archivo, o el tamao del archivo excedi el mximo permitido por su configuracin PHP. Por favor, lea el FAQ 1.16.';
$strNoDescription = 'Sin descripcin';
$strNoDetailsForEngine = 'No existe informacin detallada acerca de las condiciones en que se encuentra este motor de almacenamiento.';
$strNoDropDatabases = 'Los enunciados \"DROP DATABASE\" estn deshabilitados.';
$strNoExplain = 'Salir de la explicacin del SQL';
$strNoFilesFoundInZip = 'No se hallaron archivos dentro del archivo ZIP!';
$strNoFrames = 'phpMyAdmin funciona mejor con un navegador que <b>reconoce frames</b>.';
$strNoIndex = 'No se ha definido el ndice!';
$strNoIndexPartsDefined = 'No se han definido las partes del ndice!';
$strNoModification = 'Sin cambios';
$strNone = 'Ninguna';
$strNo = 'No';
$strNoOptions = 'Este formato no tiene opciones';
$strNoPassword = 'Sin contrasea';
$strNoPermission = 'El servidor web no tiene permiso para guardar el archivo %s.';
$strNoPhp = 'Sin cdigo PHP';
$strNoPrivileges = 'Sin privilegios';
$strNoRights = 'Usted no tiene suficientes privilegios para estar aqu ahora!';
$strNoRowsSelected = 'No se seleccionaron filas';
$strNoSpace = 'No hay suficiente espacio para guardar el archivo %s.';
$strNoTablesFound = 'No se han encontrado tablas en la base de datos.';
$strNoThemeSupport = 'No existe soporte para Diseos personalizados (Themes), por favor, revise su configuracin y/o sus temas en el directorio %s.';
$strNotNumber = 'sto no es un nmero!';
$strNotOK = 'no recibi el OK';
$strNotSet = 'La tabla <b>%s</b> no fue hallada o no fue definida en %s';
$strNoUsersFound = 'Usuario(s) no encontrado(s).';
$strNoValidateSQL = 'Salir de la validacin del SQL';
$strNull = 'Nulo';
$strNumberOfFields = 'Nmero de campos';
$strNumberOfTables = 'Nmero de tablas';
$strNumSearchResultsInTable = '%s resultado(s) en la tabla <i>%s</i>';
$strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> resultado(s)';
$strNumTables = 'Tablas';

$strOK = 'OK';
$strOpenDocumentSpreadsheet = 'Hoja de clculo Open Document';
$strOpenDocumentText = 'Texto Open Document';
$strOpenNewWindow = 'Abrir nueva ventana de phpMyAdmin';
$strOperations = 'Operaciones';
$strOperator = 'Operador';
$strOptimizeTable = 'Optimizar la tabla';
$strOptions = 'Opciones';
$strOr = 'O';
$strOverhead = 'Residuo a depurar';
$strOverwriteExisting = 'Sobreescribir el(los) archivo(s) existente(s)';

$strPageNumber = 'Nmero de pgina:';
$strPagesToBeFlushed = 'Pginas que sern eliminadas'; 
$strPaperSize = 'Tamao del papel';
$strPartialImport = 'Importacin parcial';
$strPartialText = 'Textos parciales';
$strPasswordChanged = 'La contrasea para %s se cambi exitosamente.';
$strPassword = 'Contrasea';
$strPasswordEmpty = 'La contrasea est vaca!';
$strPasswordHashing = 'Hashing de la contrasea';
$strPasswordNotSame = 'Las contraseas no coinciden!';
$strPdfDbSchema = 'Esquema de la base de datos "%s" - Pgina %s';
$strPdfInvalidTblName = 'La tabla "%s" no existe!';
$strPdfNoTables = 'No existen tablas';
$strPDF = 'PDF';
$strPDFReportExplanation = '(Genera un reporte conteniendo los datos de una sola tabla)';
$strPDFReportTitle = 'Ttulo del reporte';
$strPerHour = 'por hora';
$strPerMinute = 'por minuto';
$strPerSecond = 'por segundo';
$strPersian = 'Persa';
$strPhoneBook = 'directorio telefnico';
$strPHP40203 = 'Usted est usando PHP 4.2.3, el cual tiene un error de codificacin en cuanto a las "cadenas de caracteres multi-byte" (mbstring). Lea el reporte 19404 de PHP. No se recomienda el uso de phpMyAdmin con esta versin de PHP.';
$strPhp = 'Crear cdigo PHP';
$strPHPVersion = 'Versin de PHP';
$strPleaseSelectPrimaryOrUniqueKey = 'Por favor, seleccione la clave primaria o una clave nica';
$strPmaDocumentation = 'Documentacin de phpMyAdmin';
$strPmaUriError = 'El contenido de <tt>$cfg[\'PmaAbsoluteUri\']</tt> DEBE constar en config.inc.php!';
$strPmaWiki = 'Wiki del phpMyAdmin';
$strPolish = 'Polaco';
$strPortrait = 'Orientacin vertical';
$strPos1 = 'Empezar';
$strPrevious = 'Previo';
$strPrimaryKeyHasBeenDropped = 'La clave primaria ha sido eliminada';
$strPrimaryKeyName = 'El nombre de la clave primaria debe ser \"PRIMARY\"';
$strPrimaryKeyWarning = '("PRIMARY" <b>exclusivamente debe</b> ser el nombre de una clave primaria!)';
$strPrimary = 'Primaria';
$strPrint = 'Imprimir';
$strPrintViewFull = 'Previsualizacin para imprimir (documento completo)';
$strPrintView = 'Vista de impresin';
$strPrivDescAllPrivileges = 'Incluye todos los privilegios excepto GRANT (CONCEDER).';
$strPrivDescAlter = 'Permite alterar la estructura de las tablas existentes.';
$strPrivDescAlterRoutine = 'Permite alterar y eliminar las rutinas almacenadas.';
$strPrivDescCreateDb = 'Permite crear nuevas bases de datos y tablas.';
$strPrivDescCreateRoutine = 'Permite crear el almacenamiento de rutinas.';
$strPrivDescCreateTbl = 'Permite la creacin de tablas nuevas.';
$strPrivDescCreateTmpTable = 'Permite la creacin de tablas temporales.';
$strPrivDescCreateUser = 'Permite crear, eliminar y cambiar el nombre de las cuentas de usuario.';
$strPrivDescCreateView = 'Permite crear nuevas vistas.';
$strPrivDescDelete = 'Permite borrar datos.';
$strPrivDescDropDb = 'Permite eliminar bases de datos y tablas.';
$strPrivDescDropTbl = 'Permite eliminar tablas.';
$strPrivDescExecute5 = 'Permite ejecutar las rutinas almacenadas.';
$strPrivDescExecute = 'Permite ejecutar procedimientos guardados; no tiene efecto en esta versin de MySQL.';
$strPrivDescFile = 'Permite importar y exportar datos de y hacia archivos.';
$strPrivDescGrant = 'Permite aadir usuarios y privilegios sin conectarse nuevamente a la tabla de privilegios.';
$strPrivDescIndex = 'Permite crear y eliminar ndices.';
$strPrivDescInsert = 'Permite insertar y reemplazar datos.';
$strPrivDescLockTables = 'Permite poner candados a las tablas para el proceso actual.';
$strPrivDescMaxConnections = 'Limita el nmero de conexiones nuevas que el usuario puede abrir por hora.';
$strPrivDescMaxQuestions = 'Limita el nmero de consultas que el usuario puede enviar al servidor por hora.';
$strPrivDescMaxUpdates = 'Limita el nmero de comandos que cambian cualquier tabla o base de datos que el usuario puede ejecutar por hora.';
$strPrivDescMaxUserConnections = 'Limita el nmero de conexiones simultneas que el usuario pueda tener.';
$strPrivDescProcess3 = 'Permite eliminar los procesos de otros usuarios.';
$strPrivDescProcess4 = 'Permite ver las consultas completas en la lista de procesos.';
$strPrivDescReferences = 'No tiene efecto en esta versin de MySQL.';
$strPrivDescReload = 'Permite volver a cargar los parmetros del servidor y depurar los cachs del servidor.';
$strPrivDescReplClient = 'Da el derecho al usuario para preguntar dnde estn los "esclavos / masters".';
$strPrivDescReplSlave = 'Necesario para los "esclavos" de replicacin.';
$strPrivDescSelect = 'Permite leer los datos.';
$strPrivDescShowDb = 'Concede acceso a la lista completa de bases de datos.';
$strPrivDescShowView = 'Permite llevar a cabo las consultas SHOW CREATE VIEW (MOSTRAR CREAR VER).';
$strPrivDescShutdown = 'Permite desconectar el servidor.';
$strPrivDescSuper = 'Permite la conexin, incluso si el nmero mximo de conexiones ha sido alcanzado; Necesario para la mayor parte de operaciones administrativas tales como montar parmetros de variables globales o matar procesos de otros usuarios.';
$strPrivDescUpdate = 'Permite cambiar los datos.';
$strPrivDescUsage = 'Sin privilegios.';
$strPrivileges = 'Privilegios';
$strPrivilegesReloaded = 'Los privilegios fueron cargados nuevamente de manera exitosa.';
$strProcedures = 'Procedimientos';
$strProcesses = 'Procesos';
$strProcesslist = 'Lista de procesos';
$strProfiling = 'Perfil/Perfilamiento';
$strProtocolVersion = 'Versin del protocolo';
$strPutColNames = 'Poner los nombres de campo en la primera hilera';

$strQBEDel = 'Borrar';
$strQBE = 'Generar una consulta';
$strQBEIns = 'Insertar';
$strQueryCache = 'Cache de consultas';
$strQueryFrame = 'Ventana de consulta';
$strQueryOnDb = 'Consulta a la base de datos <b>%s</b>:';
$strQueryResultsOperations = 'Operaciones sobre los resultados de la consulta';
$strQuerySQLHistory = 'Historial-SQL';
$strQueryStatistics = '<b>Estadsticas de consulta</b>: Desde su inicio, %s consultas han sido enviadas al servidor.';
$strQueryTime = 'La consulta tard %01.4f seg';
$strQueryType = 'Tipo de consulta';
$strQueryWindowLock = 'No sobreescribir esta consulta desde fuera de la ventana';

$strReadRequests = 'Lea las solicitudes';
$strReceived = 'Recibido';
$strRecommended = 'recomendado';
$strRecords = 'Registros';
$strReferentialIntegrity = 'Comprobar la integridad referencial:';
$strRefresh = 'Actualizar';
$strRelationalSchema = 'Esquema relacionado';
$strRelationDeleted = 'La relacin fue eliminada';
$strRelationNotWorking = 'Las opciones adicionales para trabajar con tablas vinculadas fueron desactivadas. Para saber porqu, d clic %saqu%s.';  //Features = opciones, componentes?
$strRelationsForTable = 'RELACIONES PARA LA TABLA';
$strRelations = 'Relaciones';
$strRelationView = 'Vista de relaciones';
$strReload = 'Cargar nuevamente';
$strReloadingThePrivileges = 'Cargando los privilegios nuevamente';
$strReloadPrivileges = 'Cargar los privilegios nuevamente';
$strRemoveSelectedUsers = 'Eliminar a los usuarios seleccionados';
$strRenameDatabaseOK = 'La base de datos %s ha sido cambiada de nombre a %s';
$strRenameTable = 'Cambiar el nombre de la tabla a';
$strRenameTableOK = 'Tabla %s ahora se llama %s';
$strRepairTable = 'Reparar la tabla';
$strReplaceNULLBy = 'Reemplazar NULL con';
$strReplaceTable = 'Reemplazar los datos de la tabla con los del archivo';
$strReplication = 'Replicacin';
$strReset = 'Reiniciar';
$strResourceLimits = 'Lmites de recursos';
$strRestartInsertion = 'Reinicie la insercin con %s filas';
$strReType = 'Debe volver a escribir';
$strRevokeAndDeleteDescr = 'Los usuarios an tendrn el privilegio "USAGE" hasta que los privilegios se hayan vuelto a cargar.';
$strRevokeAndDelete = 'Revocar todos los privilegios activos de los usuarios y borrarlos despus.';
$strRevokeMessage = 'Ha revocado los privilegios para %s';
$strRevoke = 'Revocar';
$strRomanian = 'Rumano';
$strRoutineReturnType = 'Muestre el tipo';
$strRoutines = 'Rutinas';
$strRowLength = 'Longitud de la fila';
$strRows = 'Filas';
$strRowsFrom = 'filas empezando de';
$strRowSize = ' Tamao de la fila ';
$strRowsModeFlippedHorizontal = 'horizontal (encabezados rotados)';
$strRowsModeHorizontal = 'horizontal';
$strRowsModeOptions = 'en modo %s y repetir los encabezados cada %s celdas';
$strRowsModeVertical = 'vertical';
$strRowsStatistic = 'Estadsticas de la fila';
$strRunning = 'ejecutndose en %s';
$strRunQuery = 'Ejecutar la consulta';
$strRunSQLQuery = 'Ejecutar la(s) consulta(s) SQL en la base de datos %s';
$strRunSQLQueryOnServer = 'Ejecute la o las consultas SQL en el servidor %s';
$strRussian = 'Ruso';

$strSave = 'Grabar';
$strSaveOnServer = 'Guardar en el servidor, en el directorio %s ';
$strSavePosition = 'Guardar posicin';
$strScaleFactorSmall = 'El factor de la escala es demasiado pequeo para poner el esquema en una pgina';
$strSearch = 'Buscar';
$strSearchFormTitle = 'Buscar en la base de datos';
$strSearchInTables = 'En la(s) tabla(s):';
$strSearchNeedle = 'Palabra(s) o valor(es) a buscar (comodn: "%"):';
$strSearchOption1 = 'al menos una de estas palabras';
$strSearchOption2 = 'Todas las palabras';
$strSearchOption3 = 'La frase exacta';
$strSearchOption4 = 'como expresin regular';
$strSearchResultsFor = 'Resultados de la bsqueda por "<i>%s</i>" %s:';
$strSearchType = 'Encontrado:';
$strSecretRequired = 'El archivo de configuracin ahora necesita salvoconducto (una frase secreta) (blowfish_secret).';
$strSelectADb = 'Seleccionar una base de datos';
$strSelectAll = 'Seleccionar todo';
$strSelectBinaryLog = 'Seleccionar el log binario que desea examinar';
$strSelectFields = 'Seleccionar campos (al menos uno):';
$strSelectForeignKey = 'Seleccione la llave extranjera (foreign key)';
$strSelectNumRows = 'en la consulta';
$strSelectReferencedKey = 'Seleccione la llave de referencia';
$strSelectTables = 'Seleccionar tablas';
$strSend = 'Enviar (genera un archivo descargable)';
$strSent = 'Enviado';
$strServerChoice = 'Eleccin del servidor';
$strServerNotResponding = 'El servidor no est respondiendo';
$strServer = 'Servidor';
$strServers = 'Servidores';
$strServerStatusDelayedInserts = 'Delayed inserts';
$strServerStatus = 'Informacin acerca del tiempo de ejecucin del proceso principal';
$strServerStatusUptime = 'Este servidor MySQL ha estado activo durante %s. Se inici en %s.';
$strServerTabVariables = 'Variables';
$strServerTrafficNotes = '<b>Trfico del servidor</b>: Estas tablas muestran las estadsticas de trfico en la red de este servidor MySQL desde su inicio.';
$strServerVars = 'Variables y parmetros del servidor';
$strServerVersion = 'Versin del servidor';
$strSessionStartupErrorGeneral = 'Hubo errores al iniciar la sesin.  Por favor, revise los errores en la bitcora de su PHP y/o servidor web y configure correctamente su instalacin PHP.';
$strSessionValue = 'Valor de la sesin';
$strSetEnumVal = 'Si el tipo de campo es "enum" o "set", por favor ingrese los valores usando este formato: \'a\',\'b\',\'c\'...<br />Si alguna vez necesita poner una barra invertida("\") o una comilla simple ("\'") entre esos valores, siempre ponga una barra invertida. (Por ejemplo \'\\\\xyz\' o \'a\\\'b\').';
$strShowAll = 'Mostrar todo';
$strShowColor = 'Mostrar color';
$strShowDatadictAs = 'Formato del Diccionario de Datos';
$strShowFullQueries = 'Mostrar las consultas enteras';
$strShowGrid = 'Mostrar la cuadrcula';
$strShowHideLeftMenu = 'Ocultar/mostrar men izquierdo';
$strShowingBookmark = 'Mostrando el favorito';
$strShowingPhp = 'Mostrar como cdigo PHP';
$strShowingRecords = 'Mostrando registros ';
$strShowingSQL = 'Mostrando la consulta SQL';
$strShow = 'Mostrar';
$strShowOpenTables = 'Mostrar las tablas que estn abiertas';
$strShowPHPInfo = 'Mostrar la informacin de PHP';
$strShowSlaveHosts = 'Mostrar los hosts esclavos';
$strShowSlaveStatus = 'Mostrar el estado del esclavo';
$strShowStatusBinlog_cache_disk_useDescr = 'El nmero de transacciones que usaron el cache de log binario temporal pero que excedieron el valor del binlog_cache_size y usaron un archivo temporal para almacenar los enunciados de la transaccin.';
$strShowStatusBinlog_cache_useDescr = 'El nmero de transacciones que usaron el cache de log binario temporal.';
$strShowStatusCreated_tmp_disk_tablesDescr = 'El nmero de tablas temporales en el disco que fueron creados automticamente por el servidor mientras ejecuta los enunciados. Si las tablas Created_tmp_disk_tables es grande, puede incrementar el valor de tmp_table_size para hacer que las tablas temporales se basen en memoria en lugar de basarse en disco.';
$strShowStatusCreated_tmp_filesDescr = 'El nmero de archivos temporales que fueron creados por mysqld.';
$strShowStatusCreated_tmp_tablesDescr = 'El nmero de tablas temporales in-memory creadas automticamente por el servidor mientras se ejecutaban los enunciados.';
$strShowStatusDelayed_errorsDescr = 'El nmero de filas escritas con INSERT DELAYED en los cuales ocurri algn error (probablemente una llave duplicada).';
$strShowStatusDelayed_insert_threadsDescr = 'El nmero de procesos gestores INSERT DELAYED en uso. Cada tabla diferente en la cual uno usa INSERT DELAYED recibe su propio proceso.';
$strShowStatusDelayed_writesDescr = 'El nmero de filas INSERT DELAYED escritas.';
$strShowStatusFlush_commandsDescr  = 'El nmero de enunciados FLUSH ejecutados.';
$strShowStatusHandler_commitDescr = 'El nmero de enunciados COMMIT internos.';
$strShowStatusHandler_deleteDescr = 'El nmero de veces que una fila fue eliminada de una tabla.';
$strShowStatusHandler_discoverDescr = 'El servidor MySQL puede solicitar al motor de almacenamiento NDB Cluster si conoce acerca de una tabla con un nombre dado. Esto se llama descubrimiento. Handler_discover indica el nmero ocasiones que las tablas han sido descubiertas.';
$strShowStatusHandler_read_firstDescr = 'El nmero de veces en que el primer registro ha sido ledo desde un ndice. Si este valor es alto, sugiere que el servidor est haciendo gran cantidad de escaneos completos del ndice; por ejemplo, SELECT col1 FROM foo, asumiendo que col1 est indizado.';
$strShowStatusHandler_read_keyDescr = 'El nmero de solicitudes hechas para leer una fila basado en una llave. Si este valor es alto, es una buena indicacin de que sus consultas y tablas estn indizadas apropiadamente.';
$strShowStatusHandler_read_nextDescr = 'El nmero de solicitudes hechas para leer la siguiente fila en un orden clave. Este se incrementa si usted est consultando una columna ndice con un limitante de rango o si usted est haciendo un escaneo del ndice.';
$strShowStatusHandler_read_prevDescr = 'El nmero de solicitudes hechas para leer la fila previa en un orden clave. Este mtodo de lectura se usa principalmente para optimizar a ORDER BY ... DESC.';
$strShowStatusHandler_read_rndDescr = 'El nmero de solicitudes hechas para leer una fila basado en una posicin fija. Este es alto si usted est haciendo muchas consultas que requieren el reordenamiento del resultado. Usted probablemente tiene muchas consultas que requieren que MySQL escanee tablas enteras o usted debe tener vnculos (joins) que no usan las llaves de manera apropiada.';
$strShowStatusHandler_read_rnd_nextDescr = 'El nmero de solicitudes hechas para leer la siguiente fila en el archivo de datos. Este es alto si usted est haciendo muchos escaneos de tablas. Generalmente, esto sugiere que sus tablas no estn indizadas apropiadamente o que sus consultas no estn escritas para tomar ventaja de los ndices que tiene.';
$strShowStatusHandler_rollbackDescr = 'El nmero de enunciados ROLLBACK internos.';
$strShowStatusHandler_updateDescr = 'El nmero de solicitudes hechas para actualizar una fila en una tabla.';
$strShowStatusHandler_writeDescr = 'El nmero de solicitudes hechas para insertar una fila en una tabla.';
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'El nmero de pginas conteniendo datos (sucias o limpias).';
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'El nmero de pginas actualmente sucias.';
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'El nmero de pginas en la memoria (bfer) de trnsito comn que se ha solicitado sean vaciadas.';
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'El nmero de pginas libres.';
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'El nmero de pginas aseguradas en la memoria (bfer) de trnsito comn InnoDB. Estas son pginas en fase de lectura o escritura o que no pueden ser vaciadas o removidas por alguna otra razn.';
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'El nmero de pginas ocupadas porque han sido asignadas para overhead administrativo tales como row locks o el ndice hash adaptativo. Este valor tambin puede ser calculado como Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Tamao total de la memoria (bfer) de trnsito comn, en pginas.';
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'El nmero de read-aheads InnoDB "aleatorias" iniciadas. Esto sucede cuando una consulta va a escanear una gran porcin de una tabla pero en orden aleatorio.';
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'El nmero de read-aheads InnoDB secuenciales iniciadas. Esto sucede cuando InnoDB hace un escaneo secuencial de la tabla completa.';
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'El nmero de solicitudes de lectura lgica hechas por InnoDB.';
$strShowStatusInnodb_buffer_pool_readsDescr = 'El nmero de lecturas lgicas que InnoDB no pudo satisfacer de la memoria (bfer) de trnsito comn y donde fue necesario hacer lectura de pgina sencilla.';
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normalmente, las escrituras a la memoria de trnsito comn InnoDB suceden en el trasfondo. Sin embargo, de ser necesario leer o crear una pgina y existen pginas limpias disponibles, es necesario esperar que las pginas sean vaciadas previamente. Este contador cuenta las instancias de estas esperas. Si los parmetros del tamao de la memoria de trnsito comn se fijaron apropiadamente, este valor ser pequeo.';
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'El nmero de escrituras hechas a la memoria de trnsito comn InnoDB.';
$strShowStatusInnodb_data_fsyncsDescr = 'El nmero de operaciones fsync() hechas hasta el momento.';
$strShowStatusInnodb_data_pending_fsyncsDescr = 'El nmero actual de operaciones fsync() pendientes.';
$strShowStatusInnodb_data_pending_readsDescr = 'El nmero actual de lecturas pendientes.';
$strShowStatusInnodb_data_pending_writesDescr = 'El nmero actual de escrituras pendientess.';
$strShowStatusInnodb_data_readDescr = 'El nmero de datos ledos hasta el momento, en bytes.';
$strShowStatusInnodb_data_readsDescr = 'El nmero total de lectura de datos.';
$strShowStatusInnodb_data_writesDescr = 'El nmero total de escritura de datos.';
$strShowStatusInnodb_data_writtenDescr = 'La cantidad de datos escritas hasta el momento, en bytes.';
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'El nmero de escrituras doublewrite que se han ejecutado y el nmero de pginas escritas con este propsito.';
$strShowStatusInnodb_dblwr_writesDescr = 'El nmero de escrituras doublewrite que se han ejecutado y el nmero de pginas escritas con este propsito.';
$strShowStatusInnodb_log_waitsDescr = 'El nmero de esperas generadas porque la memoria (bfer) log fue demasiado pequea y hubo que esperar a que fuera vaciada antes de continuar.';
$strShowStatusInnodb_log_write_requestsDescr = 'El nmero de solicitudes de escritura al log.';
$strShowStatusInnodb_log_writesDescr = 'El nmero de escrituras fsicas al archivo log.';
$strShowStatusInnodb_os_log_fsyncsDescr = 'El nmero de escrituras fsyncs hechas al archivo log.';
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'El nmero de fsyncs pendientes al archivo log.';
$strShowStatusInnodb_os_log_pending_writesDescr = 'Escrituras pendientes al archivo log.';
$strShowStatusInnodb_os_log_writtenDescr = 'El nmero de bytes escritos al archivo log.';
$strShowStatusInnodb_pages_createdDescr = 'El nmero de pginas creadas.';
$strShowStatusInnodb_page_sizeDescr = 'El tamao de pgina InnDB precompilado (por omisin 16KB). Muchos valores son contados por pginas; el tamao de la pgina permite que pueda convertirse fcilmente a bytes.';
$strShowStatusInnodb_pages_readDescr = 'El nmero de pginas ledas.';
$strShowStatusInnodb_pages_writtenDescr = 'El nmero de pginas escritas.';
$strShowStatusInnodb_row_lock_current_waitsDescr = 'El nmero de row locks que actualmente estn en espera.';
$strShowStatusInnodb_row_lock_time_avgDescr = 'El tiempo promedio para adquirir un row lock, en milisegundos.';
$strShowStatusInnodb_row_lock_timeDescr = 'El total de tiempo invertido para adquirir los row locks, en milisegundos.';
$strShowStatusInnodb_row_lock_time_maxDescr = 'El tiempo mximo para adquirir un row lock, en milisegundos.';
$strShowStatusInnodb_row_lock_waitsDescr = 'El nmero de veces que un row lock tuvo que esperarse.';
$strShowStatusInnodb_rows_deletedDescr = 'El nmero de filas eliminadas de tablas InnoDB.';
$strShowStatusInnodb_rows_insertedDescr = 'El nmero de filas insertadas en tablas InnoDB.';
$strShowStatusInnodb_rows_readDescr = 'El nmero de filas ledas de las tablas InnoDB.';
$strShowStatusInnodb_rows_updatedDescr = 'El nmero de filas actualizadas en tablas InnoDB.';
$strShowStatusKey_blocks_not_flushedDescr = 'El nmero de key blocks en el key cache que han cambiado pero que an no han sido vaciados al disco. Antes se conoca como Not_flushed_key_blocks.';
$strShowStatusKey_blocks_unusedDescr = 'El nmero de bloques sin usar en el key cache. Puede usar este valor para determinar cunto del key cache est en uso.';
$strShowStatusKey_blocks_usedDescr = 'El nmero de bloques usados en el key cache. Este valor es un marcador de desbordamiento que indica el nmero mximo de bloques que algn momento se llegaron a usar.';
$strShowStatusKey_read_requestsDescr = 'El nmero de solicitudes para leer un key block desde el cache.';
$strShowStatusKey_readsDescr = 'El nmero de lecturas fsicas del key block desde el disco. Si el Key_reads es grande, entonces el valor key_buffer_size probablemente es demasiado pequeo. La tasa de fallos en el cache puede calcularse como Key_reads/Key_read_requests.';
$strShowStatusKey_write_requestsDescr = 'El nmero de solicitudes para escribir un key block al cache.';
$strShowStatusKey_writesDescr = 'El nmero de escrituras fsicas a un key block al disco.';
$strShowStatusLast_query_costDescr = 'El costo total de la ltima consulta compilada como fuera computada por el optimizador de consultas. Es til para comparar el costo de diferentes planes de consulta para una misma consulta. El valor por omisin de 0 significa que ninguna consulta ha sido compilada todava.';
$strShowStatusNot_flushed_delayed_rowsDescr = 'El nmero de filas esperando ser escritas en las colas INSERT DELAYED.';
$strShowStatusOpened_tablesDescr = 'El nmero de tablas que han sido abiertas. Si el nmero de tablas abiertas es grande, su valor del cache de tabla probablemente es muy pequeo.';
$strShowStatusOpen_filesDescr = 'El nmero de archivos que estn abiertos.';
$strShowStatusOpen_streamsDescr = 'El nmero de flujos de datos que estn abiertos (usado principalmente para alimentar a los logs).';
$strShowStatusOpen_tablesDescr = 'El nmero de tablas que estn abiertas.';
$strShowStatusQcache_free_blocksDescr = 'El nmero de bloques de memoria libre en el cache de consultas.';
$strShowStatusQcache_free_memoryDescr = 'La cantidad de memoria libre para el cache de consultas.';
$strShowStatusQcache_hitsDescr = 'El nmero de hits al cache.';
$strShowStatusQcache_insertsDescr = 'El nmero de consultas aadidos al cache.';
$strShowStatusQcache_lowmem_prunesDescr = 'El nmero de consultas que han sido removidos del cache para liberar la memoria para poner nuevas consultas en el cache. Esta informacin puede ayudar a afinar el tamao del cache de consultas. El cache de consultas usa la estrategia Least Recently Used (LRU) para decidir cules consultas deben ser removidas del cache.';
$strShowStatusQcache_not_cachedDescr = 'El nmero de consultas que no ingresaron al cache (porque no es posible o porque el parmetro no est activado en query_cache_type).';
$strShowStatusQcache_queries_in_cacheDescr = 'El nmero de consultas registradas en el cache.';
$strShowStatusQcache_total_blocksDescr = 'El nmero total de bloques en el cache de consultas.';
$strShowStatusReset = 'Resetear';
$strShowStatusRpl_statusDescr = 'El estado de la replicacin a prueba de fallos (an no ha sido implementada).';
$strShowStatusSelect_full_joinDescr = 'El nmero de vnculos (joins) que no usan ndices. Si este valor no es 0, deber revisar los ndices de sus tablas cuidadosamente.';
$strShowStatusSelect_full_range_joinDescr = 'El nmero de vnculos (joins) que usaron bsqueda por rangos en una tabla de referencias.';
$strShowStatusSelect_range_checkDescr = 'El nmero de vnculos (joins) sin keys que revisan el uso de key luego de cada fila. (Si no es 0, deber revisar los ndices de sus tablas cuidadosamente.)';
$strShowStatusSelect_rangeDescr = 'El nmero de vnculos (joins) que usaron rangos en la primera tabla. (Normalmente no es crtico aun cuando sea grande.)';
$strShowStatusSelect_scanDescr = 'El nmero de vnculos (joins) que hicieron un escaneo completo de la primera tabla.';
$strShowStatusSlave_open_temp_tablesDescr = 'El nmero de tablas temporales actualmente abiertas por el proceso SQL esclavo.';
$strShowStatusSlave_retried_transactionsDescr = 'Nmero total de veces (desde el arranque) que el proceso SQL esclavo de replicacin ha reintentado hacer transacciones.';
$strShowStatusSlave_runningDescr = 'Est ENCENDIDO si este servidor es un esclavo que est conectado a un master.';
$strShowStatusSlow_launch_threadsDescr = 'El nmero de procesos que han tomado ms de los segundos registrados en slow_launch_time para crear.';
$strShowStatusSlow_queriesDescr = 'El nmero de consultas que han tomado ms segundos que los registrados en long_query_time.';
$strShowStatusSort_merge_passesDescr = 'El nmero de pasadas de fusin (merge) que el algoritmo organizar ha debido hacer. Si este valor es grande, debe considerar incrementar el valor de la varible de sistema sort_buffer_size.';
$strShowStatusSort_rangeDescr = 'El nmero de consultas organizar que se ejecutaron con rangos.';
$strShowStatusSort_rowsDescr = 'El nmero de filas sorted.';
$strShowStatusSort_scanDescr = 'El nmero de consultas organizar que se hicieron escaneando la tabla.';
$strShowStatusTable_locks_immediateDescr = 'El nmero de veces que un table lock fue adquirido inmediatamente.';
$strShowStatusTable_locks_waitedDescr = 'El nmero de veces que un table lock no pudo adquirirse inmediatamente y fue necesaria una espera. Si este valor es alto, y hay problemas de rendimiento, primero deber optimizar sus consultas, y luego, ya sea partir sus tablas o usar replicacin.';
$strShowStatusThreads_cachedDescr = 'El nmero de procesos en el cache de procesos. La tasa de hits al cache puede calcularse como Threads_created/Connections. Si este valor es rojo, debe incrementar su thread_cache_size.';
$strShowStatusThreads_connectedDescr = 'El nmero de conexiones abiertas actualmente.';
$strShowStatusThreads_createdDescr = 'El nmero de procesos creados para manejar las conexiones. Si Threads_created es grande, querr incrementar el valor thread_cache_size. (Normalmente esto no aporta una mejora notable en el rendimiento si usted tiene una buena implementacin de procesos.)';
$strShowStatusThreads_runningDescr = 'El nmero de procesos que no estn en reposo.';
$strShowTableDimension = 'Mostrar la dimensin de las tablas';
$strShowTables = 'Mostrar las tablas';
$strShowThisQuery = ' Mostrar esta consulta otra vez ';
$strSimplifiedChinese = 'Chino simplificado';
$strSingly = '(solamente)';
$strSize = 'Tamao';
$strSkipQueries = 'Nmero de registros (consultas) a saltarse desde el inicio';
$strSlovak = 'Eslovaco'; 
$strSlovenian = 'Esloveno';
$strSmallBigAll = 'Pequeo/grande todos';
$strSnapToGrid = 'Cuadrcula magntica';
$strSocketProblem = '(o el socket del servidor MySQL local no est configurado correctamente)';
$strSortByKey = 'Organizar segn la clave';
$strSorting = 'Organizando (sorting)';
$strSort = 'Ordenar';
$strSpaceUsage = 'Espacio utilizado';
$strSpanish = 'Espaol';
$strSplitWordsWithSpace = 'Palabras separadas por un espacio (" ").';
$strSQLCompatibility = 'Modalidad compatible con SQL';
$strSQLExportType = 'Tipo de exportacin';
$strSQLParserBugMessage = 'Hay la posibilidad de que usted haya encontrado un error en el intrprete de SQL. Por favor examine cuidadosamente su consulta, y verifique que las comillas estn siendo usadas adecuadamente y hacen juego. Otra posible causa del fallo es que usted este subiendo un archivo con datos binarios por fuera del rea de texto delimitado. Intente su consulta en la interfaz de comandos de MySQL. La salida generada por el servidor de MySQL, de existir, aparece abajo, en cuyo caso puede ayudar a diagnosticar el problema. Si an tiene problemas o el intrprete falla en tanto que en la interfaz de comandos funciona, por favor reduzca la salida de su consulta de SQL a la consulta que genera el problema, y enve un reporte de error con la cadena de datos en la seccin de CORTE indicada abajo:';
$strSQLParserUserError = 'Parece haber un error en su consulta de SQL. La salida generada por el servidor de MySQL, de existir, aparece abajo, en cuyo caso puede ayudar a diagnosticar el problema.';
$strSQLQuery = 'consulta SQL';
$strSQLResult = 'Resultado SQL';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'El identificador no es vlido';
$strSQPBugUnclosedQuote = 'Comillas sin cerrar';
$strSQPBugUnknownPunctuation = 'Signo de puntuacin desconocido';
$strStandInStructureForView = 'Estructura Stand-in para la vista';
$strStatCheckTime = 'ltima revisin';
$strStatCreateTime = 'Creacin';
$strStatement = 'Enunciado';
$strStatisticsOverrun = 'En un servidor que se encuentra ejecutando procesos, los contadores de bytes pueden excederse.  Por tanto, las estadsticas reportadas por el servidor MySQL pueden estar incorrectas.';
$strStatUpdateTime = 'ltima actualizacin';
$strStatus = 'Estado actual';
$strStorageEngine = 'Motor de almacenamiento';
$strStorageEngines = 'Motores de almacenamiento';
$strStrucCSV = 'Datos CSV ';
$strStrucData = 'Estructura y datos';
$strStrucExcelCSV = 'CSV para datos de MS Excel';
$strStrucNativeExcel = 'Datos de MS Excel en formato nativo';
$strStrucOnly = 'nicamente la estructura ';
$strStructPropose = 'Planteamiento de la estructura de tabla';
$strStructure = 'Estructura';
$strStructureForView = 'Estructura para la vista';
$strSubmit = 'Enviar';
$strSuccess = 'Su consulta se ejecut con xito';
$strSuhosin = 'El servidor est utilizando Suhosin. Por favor, refirase a %sdocumentation%s para posibles ajustes.';
$strSum = 'Nmero de filas';
$strSwedish = 'Sueco';
$strSwitchToDatabase = 'Seleccionar la base de datos copiada';
$strSwitchToTable = 'Cambiar (switch) a la tabla copiada';

$strTableAlreadyExists = 'La tabla %s ya existe!';
$strTableComments = 'Comentarios de la tabla';
$strTableEmpty = 'El nombre de la tabla est vaco!';
$strTableHasBeenDropped = 'Se ha eliminado la tabla %s';
$strTableHasBeenEmptied = 'Se ha vaciado la tabla %s';
$strTableHasBeenFlushed = 'Se ha vaciado el cach de la tabla %s';
$strTableIsEmpty = 'La tabla, parece estar vaca!';
$strTableMaintenance = 'Mantenimiento de la tabla';
$strTableName = 'Nombre de la tabla';
$strTableOfContents = 'Tabla de contenidos';
$strTableOptions = 'Opciones de la tabla';
$strTables = '%s tabla(s)';
$strTableStructure = 'Estructura de tabla para la tabla';
$strTable = 'Tabla';
$strTakeIt = 'tmelo';
$strTblPrivileges = 'Privilegios especficos para la tabla';
$strTempData = 'Datos temporales';
$strTextAreaLength = ' Debido a su longitud,<br /> este campo podra no ser editable ';
$strThai = 'Tailands';
$strThemeDefaultNotFound = 'No se hall la plantilla de interfaz (theme) predeterminada %s!';
$strThemeNoPreviewAvailable = 'No existe una previsualizacin disponible.';
$strThemeNotFound = 'No se hall la plantilla de interfaz (theme) %s!';
$strThemeNoValidImgPath = 'No se hall la ruta de imgenes para la plantilla de interfaz (theme) %s!';
$strThemePathNotFound = 'No se hall la ruta de la plantilla de interfaz (theme) para la plantilla %s!';
$strTheme = 'Tema / Estilo';
$strThisHost = 'Este Host';
$strThreads = 'Procesos';
$strThreadSuccessfullyKilled = 'El proceso %s fue destruido exitosamente.';
$strTimeoutInfo = 'Se agot el tiempo de ejecucin en la importacin previa; si lo reenva continuar desde la posicin %d.';
$strTimeoutNothingParsed = 'Sin embargo, en la ejecucin ms reciente no se procesaron datos.  Esto usualmente significa que phpMyAdmin no ser capaz de completar esta importacin a menos que usted incremente el tiempo de ejecucin de php.';
$strTimeoutPassed = 'Se ha agotado el tiempo de ejecucin del script; si desea completar la importacin, por favor, reenve el mismo archivo y la importacin continuar.';
$strTime = 'Tiempo';
$strToFromPage = 'pgina de/a la';
$strToggleScratchboard = 'cambiar el estado del scratchboard';
$strToggleSmallBig = 'Alterne entre pequeo y grande';
$strToSelectRelation = 'Para seleccionar la relacin, d clic en:';
$strTotal = 'total';
$strTotalUC = 'Total';
$strTraditionalChinese = 'Chino tradicional';
$strTraditionalSpanish = 'Espaol tradicional';
$strTraffic = 'Trfico';
$strTransactionCoordinator = 'Coordinador de transaccin';
$strTransformation_application_octetstream__download = 'Mostrar un enlace para descargar los datos binarios de un campo. La primera opcin es el nombre del archivo binario.  La segunda opcin es un nombre de campo factible de una fila de la tabla que contiene el nombre del campo. Si usted aporta una segunda opcin, necesariamente deber consignar la primera opcin a una cadena de caracteres vaca';
$strTransformation_application_octetstream__hex = 'Muestra los datos en representacin hexadecimal. El primer parmetro es opcional y especifica cun a menudo se aadir espacio (2 nibbles, es decir, 1 byte de manera predeterminada).';
$strTransformation_image_jpeg__inline = 'Muestra un thumbnail que puede abrirse mediante un clic; opciones: width, height en pxeles (mantiene la proporcin original)';
$strTransformation_image_jpeg__link = 'Muestra un enlace a esta imagen (i.e., blob descarga directa).';
$strTransformation_image_png__inline = 'Ver imagen/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Toma un campo TIME, TIMESTAMP o DATETIME y lo formatea usando su formato de fechas local. La primera opcin es el offset (en horas) que se aadir al timestamp (Predeterminado: 0). La segunda opcin es un dateformat diferente de acuerdo con los parmetros disponibles para el strftime() del PHP. La tercera opcin determina si usted quiere ver la fecha local o la UTC (use strings "local" o "utc") para eso. Segn eso, el formato de la fecha tendr un valor diferente - para "local" mire la documentacin para la funcin strftime() del PHP y para "utc" se hace usando la funcin gmdate().';
$strTransformation_text_plain__external = 'LINUX SOLAMENTE: Ejecuta una aplicacin externa y alimenta el fielddata mediante input estndar. Retorna el output estndar de la aplicacin. El predeterminado es Tidy, para mostrar cdigo HTML agradable para la impresin. Por razones de seguridad, debe editar manualmente el archivo libraries/transformations/text_plain__external.inc.php e insertar las herramientas que permitir se ejecuten. La primera opcin ser el nmero del programa que querr utilizar y la segunda opcin son los parmetros para el programa. El tercer parmetro, de ser 1 convertir el output usando htmlspecialchars() (el predeterminado es 1). Un cuarto parmetro, de ser 1 pondr un NOWRAP a la celda de contenido para que todo el output se muestre sin reformatear (Predeterminado 1)';
$strTransformation_text_plain__formatted = 'Mantiene el formato original del campo. No se puede hacer Escape.';
$strTransformation_text_plain__imagelink = 'Muestra una imagen y un enlace, el campo contiene el nombre del archivo; la primera opcin es un prefijo como "http://dominio.com/", la segunda opcin es el ancho en pxeles, el tercero es el alto.';
$strTransformation_text_plain__link = 'Muestra un enlace, el campo contiene el nombre del archivo; la primera opcin es un prefijo como "http://dominio.com/", la segunda opcin es un ttulo para el enlace.';
$strTransformation_text_plain__sql = 'Formatea el texto como una consulta SQL y resalta la sintaxis.';
$strTransformation_text_plain__substr = 'Muestra una parte de una cadena de caracteres. La primera opcin es el nmero de caracteres a pasar por alto desde el principio de la cadena de caracteres (Predeterminado: 0). La segunda opcin es el nmero de caracteres a mostrar (Predeterminado: hasta el final de la cadena de caracteres). La tercera opcin es la cadena de caracteres a adjuntar y/o anteponer cuando haya truncamiento (Predeterminado: "...").';
$strTriggers = '(Evento) desencadenante';
$strTruncateQueries = 'Truncar las consultas que ya se han mostrado';
$strTurkish = 'Turco';
$strType = 'Tipo';

$strUkrainian = 'Ucraniano';
$strUncheckAll = 'Desmarcar todos';
$strUnicode = 'Unicode';
$strUnique = 'nico';
$strUnknown = 'desconocido';
$strUnselectAll = 'Deseleccionar todo';
$strUnsupportedCompressionDetected = 'Usted intent cargar un archivo con un tipo de compresin desconocido (%s). Este tipo de compresin puede no estar implementado o quiz no ha sido habilitado en su archivo de configuracin.';
$strUpdatePrivMessage = 'Ha actualizado los privilegios para %s.';
$strUpdateProfileMessage = 'Se actualiz el perfil.';
$strUpdateQuery = 'Modificar la consulta';
$strUpdComTab = 'Para actualizar su tabla Columna_comentarios (Column_comments), por favor revise la documentacin';
$strUpgrade = 'Usted debera actualizar su %s a la versin %s o ms reciente.';
$strUploadErrorCantWrite = 'No fue posible grabar el archivo al disco.';
$strUploadErrorExtension = 'La carga del archivo fue detenida por extensin.';
$strUploadErrorFormSize = 'El archivo que intent cargar excede la directiva MAX_FILE_SIZE especificada en el formulario HTML.';
$strUploadErrorIniSize = 'El archivo que intent cargar excede la directiva upload_max_filesize en php.ini.';
$strUploadErrorNoTempDir = 'No existe una carpeta temporal.';
$strUploadErrorPartial = 'El archivo que intent cargar no alcanz el 100%.';
$strUploadErrorUnknown = 'Error desconocido durante la carga del archivo.';
$strUploadLimit = 'Usted probablemente intent cargar un archivo demasiado grande.  Por favor, refirase a %sdocumentation%s para hallar modos de superar esta limitante.';
$strUploadsNotAllowed = 'No est permitido subir archivos a este servidor.';
$strUsage = 'Uso';
$strUseBackquotes = 'Usar "backquotes" con tablas y nombres de campo';
$strUsedPhpExtensions = 'Extensiones PHP utilizadas';
$strUseHostTable = 'Usar la tabla Anfitrin (Host)';
$strUserAlreadyExists = 'El usuario %s ya existe!';
$strUserEmpty = 'El nombre de usuario est vaco!';
$strUserName = 'Nombre de usuario';
$strUserNotFound = 'El usuario que seleccion no se hall en la tabla de privilegios.';
$strUserOverview = 'Vista global de usuarios';
$strUsersDeleted = 'Los usuarios seleccionados fueron borrados exitosamente.';
$strUsersHavingAccessToDb = 'Usuarios con acceso a &quot;%s&quot;';
$strUser = 'Usuario';
$strUseTabKey = 'Use la tecla TAB para saltar de un valor a otro, o CTRL+flechas para moverse a cualquier parte';
$strUseTables = 'Usar tablas';
$strUseTextField = 'Use el campo de texto';
$strUseThisValue = 'Use este valor';

$strValidateSQL = 'Validar el SQL';
$strValidatorError = 'El validador de SQL no pudo inicializarse. Por favor revise si ha instalado las extensiones php necesarias, como estn descritas en la %sdocumentacin%s.';
$strValue = 'Valor';
$strVar = 'Variable';
$strVersionInformation = 'Acerca de esta versin';
$strViewDumpDatabases = 'Ver el volcado (schema) de la base de datos';
$strViewDumpDB = 'Ver el volcado esquema de la base de datos';
$strViewDump = 'Mostrar el volcado esquema de la tabla';
$strViewHasBeenDropped = 'Se descart el modo de visualizacin %s';
$strViewMaxExactCount = 'Esta visualizacin tiene ms de %s filas. Por favor, refirase a la %sdocumentacin%s.';
$strViewName = '(VIEW) VER nombre';
$strView = 'Visualizar';

$strWebServerUploadDirectory = 'directorio en el servidor web para subir los archivos';
$strWebServerUploadDirectoryError = 'No est disponible el directorio que usted habilit para subir las tareas';
$strWelcome = 'Bienvenido a %s';
$strWestEuropean = 'Europea occidental';
$strWildcard = 'comodn';
$strWindowNotFound = 'La ventana del navegador no pudo actualizarse. Quiz cerr la ventana principal o su navegador est bloqueando las actualizaciones en ventanas mltiples debido a sus parmetros de seguridad.';
$strWithChecked = 'Para los elementos que estn marcados:';
$strWriteRequests = 'Escribir las solicitudes';
$strWrongUser = 'El nombre de usuario o la contrasea est equivocado. El acceso fue denegado.';

$strXML = 'XML';

$strYes = 'S';

$strZeroRemovesTheLimit = 'Nota: si cambia los parmetros de estas opciones a 0 (cero), remueve el lmite.';
$strZip = '"comprimido con zip"';

?>
